
## CATO-CLI - mutation.sites.removeSecondaryAwsVSocket:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sites.removeSecondaryAwsVSocket) for documentation on this operation.

### Usage for mutation.sites.removeSecondaryAwsVSocket:

```bash
catocli mutation sites removeSecondaryAwsVSocket -h

catocli mutation sites removeSecondaryAwsVSocket <json>

catocli mutation sites removeSecondaryAwsVSocket --json-file mutation.sites.removeSecondaryAwsVSocket.json

catocli mutation sites removeSecondaryAwsVSocket '{"socketId":"id"}'

catocli mutation sites removeSecondaryAwsVSocket '{
    "socketId": "id"
}'
```

#### Operation Arguments for mutation.sites.removeSecondaryAwsVSocket ####

`accountId` [ID] - (required) N/A    
`socketId` [ID] - (required) N/A    
